from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class video_morpher(FastClient):
    """
    Generated client for fofr/video-morpher
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0ce78050-64c8-4968-aa57-74b52618ac0e", api_key=api_key)
    
    def predictions(self, subject_image_1: Union[MediaFile, str, bytes], subject_image_2: Union[MediaFile, str, bytes], subject_image_3: Union[MediaFile, str, bytes], subject_image_4: Union[MediaFile, str, bytes], mode: str = 'medium', prompt: str = '', checkpoint: str = 'realistic', aspect_ratio: str = '2:3', style_strength: float = 1.0, use_controlnet: bool = True, negative_prompt: str = '', seed: Optional[int] = None, style_image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            subject_image_1: The first subject of the video
            
            subject_image_2: The second subject of the video
            
            subject_image_3: The third subject of the video
            
            subject_image_4: The fourth subject of the video
            
            mode: Determines if you produce a quick experimental video or an upscaled interpolated one. (small ~20s, medium ~60s, upscaled ~2min, upscaled-and-interpolated ~4min) Defaults to 'medium'.
            
            prompt: The prompt has a small effect, but most of the video is driven by the subject images Defaults to ''.
            
            checkpoint: The checkpoint to use for the model Defaults to 'realistic'.
            
            aspect_ratio: The aspect ratio of the video Defaults to '2:3'.
            
            style_strength: How strong the style is applied Defaults to 1.0.
            
            use_controlnet: Use geometric circles to guide the generation Defaults to True.
            
            negative_prompt: What you do not want to see in the video Defaults to ''.
            
            seed: Set a seed for reproducibility. Random by default. Optional.
            
            style_image: Apply the style from this image to the whole video Optional.
            
        """
        return self.submit_job("/predictions", subject_image_1=subject_image_1, subject_image_2=subject_image_2, subject_image_3=subject_image_3, subject_image_4=subject_image_4, mode=mode, prompt=prompt, checkpoint=checkpoint, aspect_ratio=aspect_ratio, style_strength=style_strength, use_controlnet=use_controlnet, negative_prompt=negative_prompt, seed=seed, style_image=style_image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class animesr(FastClient):
    """
    Generated client for tencentarc/animesr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9d1a68b0-d400-4323-9e29-2a16c828f0e1", api_key=api_key)
    
    def predictions(self, video: Optional[Union[MediaFile, str, bytes]] = None, frames: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video file Optional.
            
            frames: Zip file of frames of a video. Ignored when video is provided. Optional.
            
        """
        return self.submit_job("/predictions", video=video, frames=frames, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class inspyrenet(FastClient):
    """
    Generated client for swook/inspyrenet
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="53b61825-79f2-4503-bfd0-a5538c7d3610", api_key=api_key)
    
    def predictions(self, image_path: Union[MediaFile, str, bytes], **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image_path: RGB input image
            
        """
        return self.submit_job("/predictions", image_path=image_path, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class diffbir(FastClient):
    """
    Generated client for zsxkib/diffbir
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bc7d5e09-7819-4faf-8576-0d637be0cd75", api_key=api_key)
    
    def predictions(self, input: Union[MediaFile, str, bytes], seed: int = 231, steps: int = 50, tiled: bool = False, tile_size: int = 512, has_aligned: bool = False, tile_stride: int = 256, repeat_times: int = 1, use_guidance: bool = False, color_fix_type: str = 'wavelet', guidance_scale: float = 0.0, guidance_space: str = 'latent', guidance_repeat: int = 5, only_center_face: bool = False, guidance_time_stop: int = -1, guidance_time_start: int = 1001, background_upsampler: str = 'RealESRGAN', face_detection_model: str = 'retinaface_resnet50', upscaling_model_type: str = 'general_scenes', restoration_model_type: str = 'general_scenes', super_resolution_factor: int = 4, disable_preprocess_model: bool = False, reload_restoration_model: bool = False, background_upsampler_tile: int = 400, background_upsampler_tile_stride: int = 400, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input: Path to the input image you want to enhance.
            
            seed: Random seed to ensure reproducibility. Setting this ensures that multiple runs with the same input produce the same output. Defaults to 231.
            
            steps: The number of enhancement iterations to perform. More steps might result in a clearer image but can also introduce artifacts. Defaults to 50.
            
            tiled: Whether to use patch-based sampling. This can be useful for very large images to enhance them in smaller chunks rather than all at once. Defaults to False.
            
            tile_size: Size of each tile (or patch) when 'tiled' option is enabled. Determines how the image is divided during patch-based enhancement. Defaults to 512.
            
            has_aligned: For 'faces' mode: Indicates if the input images are already cropped and aligned to faces. If not, the model will attempt to do this. Defaults to False.
            
            tile_stride: Distance between the start of each tile when the image is divided for patch-based enhancement. A smaller stride means more overlap between tiles. Defaults to 256.
            
            repeat_times: Number of times the enhancement process is repeated by feeding the output back as input. This can refine the result but might also introduce over-enhancement issues. Defaults to 1.
            
            use_guidance: Use latent image guidance for enhancement. This can help in achieving more accurate and contextually relevant enhancements. Defaults to False.
            
            color_fix_type: Method used for color correction post enhancement. 'wavelet' and 'adain' offer different styles of color correction, while 'none' skips this step. Defaults to 'wavelet'.
            
            guidance_scale: For 'general_scenes': Scale factor for the guidance mechanism. Adjusts the influence of guidance on the enhancement process. Defaults to 0.0.
            
            guidance_space: For 'general_scenes': Determines in which space (RGB or latent) the guidance operates. 'latent' can often provide more subtle and context-aware enhancements. Defaults to 'latent'.
            
            guidance_repeat: For 'general_scenes': Number of times the guidance process is repeated during enhancement. Defaults to 5.
            
            only_center_face: For 'faces' mode: If multiple faces are detected, only enhance the center-most face in the image. Defaults to False.
            
            guidance_time_stop: For 'general_scenes': Specifies when (at which step) the guidance mechanism stops influencing the enhancement. Defaults to -1.
            
            guidance_time_start: For 'general_scenes': Specifies when (at which step) the guidance mechanism starts influencing the enhancement. Defaults to 1001.
            
            background_upsampler: For 'faces' mode: Model used to upscale the background in images where the primary subject is a face. Defaults to 'RealESRGAN'.
            
            face_detection_model: For 'faces' mode: Model used for detecting faces in the image. Choose based on accuracy and speed preferences. Defaults to 'retinaface_resnet50'.
            
            upscaling_model_type: Choose the type of model best suited for the primary content of the image: 'faces' for portraits and 'general_scenes' for everything else. Defaults to 'general_scenes'.
            
            restoration_model_type: Select the restoration model that aligns with the content of your image. This model is responsible for image restoration which removes degradations. Defaults to 'general_scenes'.
            
            super_resolution_factor: Factor by which the input image resolution should be increased. For instance, a factor of 4 will make the resolution 4 times greater in both height and width. Defaults to 4.
            
            disable_preprocess_model: Disables the initial preprocessing step using SwinIR. Turn this off if your input image is already of high quality and doesn't require restoration. Defaults to False.
            
            reload_restoration_model: Reload the image restoration model (SwinIR) if set to True. This can be useful if you've updated or changed the underlying SwinIR model. Defaults to False.
            
            background_upsampler_tile: For 'faces' mode: Size of each tile used by the background upsampler when dividing the image into patches. Defaults to 400.
            
            background_upsampler_tile_stride: For 'faces' mode: Distance between the start of each tile when the background is divided for upscaling. A smaller stride means more overlap between tiles. Defaults to 400.
            
        """
        return self.submit_job("/predictions", input=input, seed=seed, steps=steps, tiled=tiled, tile_size=tile_size, has_aligned=has_aligned, tile_stride=tile_stride, repeat_times=repeat_times, use_guidance=use_guidance, color_fix_type=color_fix_type, guidance_scale=guidance_scale, guidance_space=guidance_space, guidance_repeat=guidance_repeat, only_center_face=only_center_face, guidance_time_stop=guidance_time_stop, guidance_time_start=guidance_time_start, background_upsampler=background_upsampler, face_detection_model=face_detection_model, upscaling_model_type=upscaling_model_type, restoration_model_type=restoration_model_type, super_resolution_factor=super_resolution_factor, disable_preprocess_model=disable_preprocess_model, reload_restoration_model=reload_restoration_model, background_upsampler_tile=background_upsampler_tile, background_upsampler_tile_stride=background_upsampler_tile_stride, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class sdxl_lightning_4step(FastClient):
    """
    Generated client for bytedance/sdxl-lightning-4step
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bfa5b88b-0143-4f31-9466-1db95a18f13b", api_key=api_key)
    
    def predictions(self, seed: int = 0, width: int = 1024, height: int = 1024, prompt: str = 'self-portrait of a woman, lightning in the background', scheduler: str = 'K_EULER', num_outputs: int = 1, guidance_scale: float = 0.0, negative_prompt: str = 'worst quality, low quality', num_inference_steps: int = 4, disable_safety_checker: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Random seed. Leave blank to randomize the seed Defaults to 0.
            
            width: Width of output image. Recommended 1024 or 1280 Defaults to 1024.
            
            height: Height of output image. Recommended 1024 or 1280 Defaults to 1024.
            
            prompt: Input prompt Defaults to 'self-portrait of a woman, lightning in the background'.
            
            scheduler: scheduler Defaults to 'K_EULER'.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 0.0.
            
            negative_prompt: Negative Input prompt Defaults to 'worst quality, low quality'.
            
            num_inference_steps: Number of denoising steps. 4 for best results Defaults to 4.
            
            disable_safety_checker: Disable safety checker for generated images Defaults to False.
            
        """
        return self.submit_job("/predictions", seed=seed, width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, negative_prompt=negative_prompt, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class stable_video_face_restoration(FastClient):
    """
    Generated client for zsxkib/stable-video-face-restoration
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="db23cabd-9b2c-434b-ba80-37e919e3f39d", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], tasks: str = 'face-restoration', overlap: int = 3, decode_chunk_size: int = 16, i2i_noise_strength: float = 1.0, noise_aug_strength: float = 0.0, num_inference_steps: int = 30, max_appearance_guidance_scale: float = 2.0, min_appearance_guidance_scale: float = 2.0, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video file (e.g. MP4).
            
            tasks: Which restoration tasks to apply. Defaults to 'face-restoration'.
            
            overlap: Number of overlapping frames between segments. Defaults to 3.
            
            decode_chunk_size: Chunk size for decoding long videos. Defaults to 16.
            
            i2i_noise_strength: Image-to-image noise strength. Defaults to 1.0.
            
            noise_aug_strength: Noise augmentation strength. Defaults to 0.0.
            
            num_inference_steps: Number of diffusion steps. Defaults to 30.
            
            max_appearance_guidance_scale: Maximum guidance scale for restoration. Defaults to 2.0.
            
            min_appearance_guidance_scale: Minimum guidance scale for restoration. Defaults to 2.0.
            
            mask: An inpainting mask image (white areas will be restored). Only required when tasks includes inpainting. Optional.
            
            seed: Random seed. Leave blank to randomize. Optional.
            
        """
        return self.submit_job("/predictions", video=video, tasks=tasks, overlap=overlap, decode_chunk_size=decode_chunk_size, i2i_noise_strength=i2i_noise_strength, noise_aug_strength=noise_aug_strength, num_inference_steps=num_inference_steps, max_appearance_guidance_scale=max_appearance_guidance_scale, min_appearance_guidance_scale=min_appearance_guidance_scale, mask=mask, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class mustango(FastClient):
    """
    Generated client for declare-lab/mustango
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e0c02659-b190-490c-8839-0684746c3730", api_key=api_key)
    
    def predictions(self, steps: int = 100, prompt: str = "This is a new age piece. There is a flute playing the main melody with a lot of staccato notes. The rhythmic background consists of a medium tempo electronic drum beat with percussive elements all over the spectrum. There is a playful atmosphere to the piece. This piece can be used in the soundtrack of a children's TV show or an advertisement jingle.", guidance: float = 3.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            steps: inference steps Defaults to 100.
            
            prompt: Input prompt. Defaults to "This is a new age piece. There is a flute playing the main melody with a lot of staccato notes. The rhythmic background consists of a medium tempo electronic drum beat with percussive elements all over the spectrum. There is a playful atmosphere to the piece. This piece can be used in the soundtrack of a children's TV show or an advertisement jingle.".
            
            guidance: guidance scale Defaults to 3.0.
            
        """
        return self.submit_job("/predictions", steps=steps, prompt=prompt, guidance=guidance, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class ram_grounded_sam(FastClient):
    """
    Generated client for idea-research/ram-grounded-sam
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="cdc115d5-e386-47a4-9b7f-8f447313f19c", api_key=api_key)
    
    def predictions(self, input_image: Union[MediaFile, str, bytes], use_sam_hq: bool = False, show_visualisation: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_image: Input image
            
            use_sam_hq: Use sam_hq instead of SAM for prediction Defaults to False.
            
            show_visualisation: Output rounding box and masks on the image Defaults to False.
            
        """
        return self.submit_job("/predictions", input_image=input_image, use_sam_hq=use_sam_hq, show_visualisation=show_visualisation, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class wan_1_3b_inpaint(FastClient):
    """
    Generated client for andreasjansson/wan-1-3b-inpaint
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="8c6671c9-d902-4c4e-9ec8-3d5e5844034b", api_key=api_key)
    
    def predictions(self, prompt: str, input_video: Union[MediaFile, str, bytes], seed: int = -1, strength: float = 0.9, expand_mask: int = 10, guide_scale: float = 5.0, sampling_steps: int = 50, negative_prompt: str = '', frames_per_second: int = 16, keep_aspect_ratio: bool = False, inpaint_fixup_steps: int = 0, mask_video: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt for inpainting the masked area
            
            input_video: Original video to be inpainted
            
            seed: Random seed. Leave blank for random Defaults to -1.
            
            strength: Strength of inpainting effect, 1.0 is full regeneration Defaults to 0.9.
            
            expand_mask: Expand the mask by a number of pixels Defaults to 10.
            
            guide_scale: Guidance scale for prompt adherence Defaults to 5.0.
            
            sampling_steps: Number of sampling steps Defaults to 50.
            
            negative_prompt: Negative prompt Defaults to ''.
            
            frames_per_second: Output video FPS Defaults to 16.
            
            keep_aspect_ratio: Keep the aspect ratio of the input video. This will degrade the quality of the inpainting. Defaults to False.
            
            inpaint_fixup_steps: Number of steps for final inpaint fixup. Ignored when in video-to-video mode (when mask_video is empty) Defaults to 0.
            
            mask_video: Mask video (white areas will be inpainted). Leave blank for video-to-video Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, input_video=input_video, seed=seed, strength=strength, expand_mask=expand_mask, guide_scale=guide_scale, sampling_steps=sampling_steps, negative_prompt=negative_prompt, frames_per_second=frames_per_second, keep_aspect_ratio=keep_aspect_ratio, inpaint_fixup_steps=inpaint_fixup_steps, mask_video=mask_video, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class zero123plusplus(FastClient):
    """
    Generated client for jd7h/zero123plusplus
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e54c61c8-e627-4ef8-b561-7680d07b7635", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], remove_background: bool = False, return_intermediate_images: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image. Aspect ratio should be 1:1. Recommended resolution is >= 320x320 pixels.
            
            remove_background: Remove the background of the input image Defaults to False.
            
            return_intermediate_images: Return the intermediate images together with the output images Defaults to False.
            
        """
        return self.submit_job("/predictions", image=image, remove_background=remove_background, return_intermediate_images=return_intermediate_images, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class mvdream(FastClient):
    """
    Generated client for adirik/mvdream
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="fc5360af-e2bf-4353-a7b2-32b701bb0fda", api_key=api_key)
    
    def predictions(self, prompt: str = 'an astronaut riding a camel', max_steps: int = 10000, guidance_scale: float = 50.0, negative_prompt: str = 'ugly, bad anatomy, blurry, pixelated obscure, unnatural colors, poor lighting, dull, and unclear, cropped, lowres, low quality, artifacts, duplicate, morbid, mutilated, poorly drawn face, deformed, dehydrated, bad proportions', seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt to generate a 3D object. Defaults to 'an astronaut riding a camel'.
            
            max_steps: Number of iterations to run the model for. Defaults to 10000.
            
            guidance_scale: Scale factor for the guidance loss. Defaults to 50.0.
            
            negative_prompt: Prompt for the negative class. If not specified, a random prompt will be used. Defaults to 'ugly, bad anatomy, blurry, pixelated obscure, unnatural colors, poor lighting, dull, and unclear, cropped, lowres, low quality, artifacts, duplicate, morbid, mutilated, poorly drawn face, deformed, dehydrated, bad proportions'.
            
            seed: The seed to use for the generation. If not specified, a random seed will be used. Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, max_steps=max_steps, guidance_scale=guidance_scale, negative_prompt=negative_prompt, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class controlnet_x_ip_adapter_realistic_vision_v5(FastClient):
    """
    Generated client for usamaehsan/controlnet-x-ip-adapter-realistic-vision-v5
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9a2ea88f-8dd0-4642-bc51-91bce767cdf0", api_key=api_key)
    
    def predictions(self, prompt: str, eta: float = 0.0, max_width: int = 512, scheduler: str = 'DDIM', guess_mode: bool = False, int_kwargs: str = '', max_height: int = 512, num_outputs: int = 1, guidance_scale: float = 7.0, ip_adapter_ckpt: str = 'ip-adapter_sd15.bin', negative_prompt: str = 'Longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality', img2img_strength: float = 0.5, ip_adapter_weight: float = 1.0, sorted_controlnets: str = 'lineart, tile, inpainting', inpainting_strength: float = 1.0, num_inference_steps: int = 20, disable_safety_check: bool = False, film_grain_lora_weight: float = 0.0, tile_conditioning_scale: float = 1.0, add_more_detail_lora_scale: float = 0.5, detail_tweaker_lora_weight: float = 0.0, lineart_conditioning_scale: float = 1.0, scribble_conditioning_scale: float = 1.0, epi_noise_offset_lora_weight: float = 0.0, brightness_conditioning_scale: float = 1.0, inpainting_conditioning_scale: float = 1.0, color_temprature_slider_lora_weight: float = 0.0, seed: Optional[int] = None, mask_image: Optional[Union[MediaFile, str, bytes]] = None, tile_image: Optional[Union[MediaFile, str, bytes]] = None, img2img_image: Optional[Union[MediaFile, str, bytes]] = None, lineart_image: Optional[Union[MediaFile, str, bytes]] = None, scribble_image: Optional[Union[MediaFile, str, bytes]] = None, brightness_image: Optional[Union[MediaFile, str, bytes]] = None, inpainting_image: Optional[Union[MediaFile, str, bytes]] = None, ip_adapter_image: Optional[Union[MediaFile, str, bytes]] = None, negative_auto_mask_text: Optional[str] = None, positive_auto_mask_text: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt - using compel, use +++ to increase words weight:: doc: https://github.com/damian0815/compel/tree/main/doc || https://invoke-ai.github.io/InvokeAI/features/PROMPTS/#attention-weighting
            
            eta: Controls the amount of noise that is added to the input data during the denoising diffusion process. Higher value -> more noise Defaults to 0.0.
            
            max_width: Max width/Resolution of image Defaults to 512.
            
            scheduler: Choose a scheduler. Defaults to 'DDIM'.
            
            guess_mode: In this mode, the ControlNet encoder will try best to recognize the content of the input image even if you remove all prompts. The `guidance_scale` between 3.0 and 5.0 is recommended. Defaults to False.
            
            int_kwargs: int_kwargs Defaults to ''.
            
            max_height: Max height/Resolution of image Defaults to 512.
            
            num_outputs: Number of images to generate Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.0.
            
            ip_adapter_ckpt: IP Adapter checkpoint Defaults to 'ip-adapter_sd15.bin'.
            
            negative_prompt: Negative prompt - using compel, use +++ to increase words weight//// negative-embeddings available ///// FastNegativeV2 , boring_e621_v4 , verybadimagenegative_v1 || to use them, write their keyword in negative prompt Defaults to 'Longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality'.
            
            img2img_strength: img2img strength, does not work when inpainting image is given, 0.1-same image, 0.99-complete destruction of image Defaults to 0.5.
            
            ip_adapter_weight: IP Adapter weight Defaults to 1.0.
            
            sorted_controlnets: Comma seperated string of controlnet names, list of names: tile, inpainting, lineart,depth ,scribble , brightness /// example value: tile, inpainting, lineart  Defaults to 'lineart, tile, inpainting'.
            
            inpainting_strength: inpainting strength Defaults to 1.0.
            
            num_inference_steps: Steps to run denoising Defaults to 20.
            
            disable_safety_check: Disable safety check. Use at your own risk! Defaults to False.
            
            film_grain_lora_weight: disabled on 0 Defaults to 0.0.
            
            tile_conditioning_scale: Conditioning scale for tile controlnet Defaults to 1.0.
            
            add_more_detail_lora_scale: Scale/ weight of more_details lora, more scale = more details, disabled on 0 Defaults to 0.5.
            
            detail_tweaker_lora_weight: disabled on 0 Defaults to 0.0.
            
            lineart_conditioning_scale: Conditioning scale for canny controlnet Defaults to 1.0.
            
            scribble_conditioning_scale: Conditioning scale for scribble controlnet Defaults to 1.0.
            
            epi_noise_offset_lora_weight: disabled on 0 Defaults to 0.0.
            
            brightness_conditioning_scale: Conditioning scale for brightness controlnet Defaults to 1.0.
            
            inpainting_conditioning_scale: Conditioning scale for inpaint controlnet Defaults to 1.0.
            
            color_temprature_slider_lora_weight: disabled on 0 Defaults to 0.0.
            
            seed: Seed Optional.
            
            mask_image: mask image for inpainting controlnet Optional.
            
            tile_image: Control image for tile controlnet Optional.
            
            img2img_image: Image2image image Optional.
            
            lineart_image: Control image for canny controlnet Optional.
            
            scribble_image: Control image for scribble controlnet Optional.
            
            brightness_image: Control image for brightness controlnet Optional.
            
            inpainting_image: Control image for inpainting controlnet Optional.
            
            ip_adapter_image: IP Adapter image Optional.
            
            negative_auto_mask_text: // seperated list of objects you dont want to mask - 'hairs // eyes // cloth'  Optional.
            
            positive_auto_mask_text: // seperated list of objects for mask, AI will auto create mask of these objects, if mask text is given, mask image will not work - 'hairs // eyes // cloth' Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, eta=eta, max_width=max_width, scheduler=scheduler, guess_mode=guess_mode, int_kwargs=int_kwargs, max_height=max_height, num_outputs=num_outputs, guidance_scale=guidance_scale, ip_adapter_ckpt=ip_adapter_ckpt, negative_prompt=negative_prompt, img2img_strength=img2img_strength, ip_adapter_weight=ip_adapter_weight, sorted_controlnets=sorted_controlnets, inpainting_strength=inpainting_strength, num_inference_steps=num_inference_steps, disable_safety_check=disable_safety_check, film_grain_lora_weight=film_grain_lora_weight, tile_conditioning_scale=tile_conditioning_scale, add_more_detail_lora_scale=add_more_detail_lora_scale, detail_tweaker_lora_weight=detail_tweaker_lora_weight, lineart_conditioning_scale=lineart_conditioning_scale, scribble_conditioning_scale=scribble_conditioning_scale, epi_noise_offset_lora_weight=epi_noise_offset_lora_weight, brightness_conditioning_scale=brightness_conditioning_scale, inpainting_conditioning_scale=inpainting_conditioning_scale, color_temprature_slider_lora_weight=color_temprature_slider_lora_weight, seed=seed, mask_image=mask_image, tile_image=tile_image, img2img_image=img2img_image, lineart_image=lineart_image, scribble_image=scribble_image, brightness_image=brightness_image, inpainting_image=inpainting_image, ip_adapter_image=ip_adapter_image, negative_auto_mask_text=negative_auto_mask_text, positive_auto_mask_text=positive_auto_mask_text, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class hunyuan3d_2(FastClient):
    """
    Generated client for prunaai/hunyuan3d-2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2060f890-7195-46af-af4c-ec0b8af12030", api_key=api_key)
    
    def predictions(self, file_type: str = 'glb', face_count: int = 40000, num_chunks: int = 20000, speed_mode: str = 'Juiced 🔥 (fast)', generator_seed: int = 12345, octree_resolution: int = 200, num_inference_steps: int = 50, image_path: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            file_type: File type Defaults to 'glb'.
            
            face_count: Target number of faces for simplification Defaults to 40000.
            
            num_chunks: Number of chunks Defaults to 20000.
            
            speed_mode: Speed optimization level Defaults to 'Juiced 🔥 (fast)'.
            
            generator_seed: Seed for random generator Defaults to 12345.
            
            octree_resolution: Octree resolution Defaults to 200.
            
            num_inference_steps: Number of inference steps Defaults to 50.
            
            image_path: Input image for hunyuan3d control Optional.
            
        """
        return self.submit_job("/predictions", file_type=file_type, face_count=face_count, num_chunks=num_chunks, speed_mode=speed_mode, generator_seed=generator_seed, octree_resolution=octree_resolution, num_inference_steps=num_inference_steps, image_path=image_path, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.nateraw.audio_super_resolution import audio_super_resolution
from socaity.sdk.replicate.nateraw.autotune import autotune
from socaity.sdk.replicate.nateraw.bge_large_en_v1_5 import bge_large_en_v1_5
from socaity.sdk.replicate.nateraw.musicgen_songstarter_v0_2 import musicgen_songstarter_v0_2
from socaity.sdk.replicate.nateraw.nous_hermes_2_solar_10_7b import nous_hermes_2_solar_10_7b
from socaity.sdk.replicate.nateraw.nous_hermes_llama2_awq import nous_hermes_llama2_awq
from socaity.sdk.replicate.nateraw.stable_diffusion_videos import stable_diffusion_videos


from fastsdk import FastClient, APISeex

class audiogen(FastClient):
    """
    Generated client for sepal/audiogen
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="736b4266-8a63-49a8-a405-7d94c1a8444b", api_key=api_key)
    
    def predictions(self, prompt: str, top_k: int = 250, top_p: float = 0.0, duration: float = 3.0, temperature: float = 1.0, output_format: str = 'wav', classifier_free_guidance: int = 3, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt that describes the sound
            
            top_k: Reduces sampling to the k most likely tokens. Defaults to 250.
            
            top_p: Reduces sampling to tokens with cumulative probability of p. When set to  `0` (default), top_k sampling is used. Defaults to 0.0.
            
            duration: Max duration of the sound Defaults to 3.0.
            
            temperature: Controls the 'conservativeness' of the sampling process. Higher temperature means more diversity. Defaults to 1.0.
            
            output_format: Output format for generated audio. Defaults to 'wav'.
            
            classifier_free_guidance: Increases the influence of inputs on the output. Higher values produce lower-varience outputs that adhere more closely to inputs. Defaults to 3.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_k=top_k, top_p=top_p, duration=duration, temperature=temperature, output_format=output_format, classifier_free_guidance=classifier_free_guidance, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class embeddings_gte_base(FastClient):
    """
    Generated client for mark3labs/embeddings-gte-base
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6ebaf097-a13d-45fb-a4f6-43212da635cd", api_key=api_key)
    
    def predictions(self, text: str, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Text string to embed
            
        """
        return self.submit_job("/predictions", text=text, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class sd_controlnet_lora(FastClient):
    """
    Generated client for pnyompen/sd-controlnet-lora
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1f2089d2-a406-4fd6-b762-496d74794321", api_key=api_key)
    
    def predictions(self, prompt: str = 'An astronaut riding a rainbow unicorn', img2img: bool = False, strength: float = 0.8, remove_bg: bool = False, scheduler: str = 'K_EULER', lora_scale: float = 0.95, num_outputs: int = 1, guidance_scale: float = 7.5, condition_scale: float = 1.1, negative_prompt: str = '', ip_adapter_scale: float = 1.0, num_inference_steps: int = 30, auto_generate_caption: bool = False, generated_caption_weight: float = 0.5, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, lora_weights: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Input prompt Defaults to 'An astronaut riding a rainbow unicorn'.
            
            img2img: Use img2img pipeline, it will use the image input both as the control image and the base image. Defaults to False.
            
            strength: When img2img is active, the denoising strength. 1 means total destruction of the input image. Defaults to 0.8.
            
            remove_bg: Remove background from the input image Defaults to False.
            
            scheduler: scheduler Defaults to 'K_EULER'.
            
            lora_scale: LoRA additive scale. Only applicable on trained models. Defaults to 0.95.
            
            num_outputs: Number of images to output Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            condition_scale: The bigger this number is, the more ControlNet interferes Defaults to 1.1.
            
            negative_prompt: Input Negative Prompt Defaults to ''.
            
            ip_adapter_scale: Scale for the IP Adapter Defaults to 1.0.
            
            num_inference_steps: Number of denoising steps Defaults to 30.
            
            auto_generate_caption: Use BLIP to generate captions for the input images Defaults to False.
            
            generated_caption_weight: Weight for the generated caption Defaults to 0.5.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
            lora_weights: Replicate LoRA weights to use. Leave blank to use the default weights. Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, img2img=img2img, strength=strength, remove_bg=remove_bg, scheduler=scheduler, lora_scale=lora_scale, num_outputs=num_outputs, guidance_scale=guidance_scale, condition_scale=condition_scale, negative_prompt=negative_prompt, ip_adapter_scale=ip_adapter_scale, num_inference_steps=num_inference_steps, auto_generate_caption=auto_generate_caption, generated_caption_weight=generated_caption_weight, seed=seed, image=image, lora_weights=lora_weights, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import List, Union, Any, Optional

from media_toolkit import MediaFile


class vace_1_3b(FastClient):
    """
    Generated client for prunaai/vace-1-3b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="44d72183-8b42-4bd5-92fb-faafd583a07e", api_key=api_key)
    
    def predictions(self, prompt: str, seed: int = -1, size: str = '480*832', frame_num: int = 81, speed_mode: str = 'Lightly Juiced 🍊 (more consistent)', sample_shift: int = 16, sample_steps: int = 50, sample_solver: str = 'unipc', sample_guide_scale: float = 5.0, src_mask: Optional[Union[MediaFile, str, bytes]] = None, src_video: Optional[Union[MediaFile, str, bytes]] = None, src_ref_images: Optional[Union[List[Any], MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt
            
            seed: Random seed (-1 for random) Defaults to -1.
            
            size: Output resolution Defaults to '480*832'.
            
            frame_num: Number of frames to generate. Defaults to 81.
            
            speed_mode: Speed optimization level Defaults to 'Lightly Juiced 🍊 (more consistent)'.
            
            sample_shift: Sample shift Defaults to 16.
            
            sample_steps: Sample steps Defaults to 50.
            
            sample_solver: Sample solver Defaults to 'unipc'.
            
            sample_guide_scale: Sample guide scale Defaults to 5.0.
            
            src_mask: Input mask video to edit. Optional.
            
            src_video: Input video to edit. Optional.
            
            src_ref_images: Input reference images to edit. Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, seed=seed, size=size, frame_num=frame_num, speed_mode=speed_mode, sample_shift=sample_shift, sample_steps=sample_steps, sample_solver=sample_solver, sample_guide_scale=sample_guide_scale, src_mask=src_mask, src_video=src_video, src_ref_images=src_ref_images, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.prunaai.flux_1_dev import flux_1_dev
from socaity.sdk.replicate.prunaai.hidream_l1_dev import hidream_l1_dev
from socaity.sdk.replicate.prunaai.hidream_l1_fast import hidream_l1_fast
from socaity.sdk.replicate.prunaai.hidream_l1_full import hidream_l1_full
from socaity.sdk.replicate.prunaai.hunyuan3d_2 import hunyuan3d_2
from socaity.sdk.replicate.prunaai.sdxl_lightning import sdxl_lightning
from socaity.sdk.replicate.prunaai.vace_14b import vace_14b
from socaity.sdk.replicate.prunaai.vace_1_3b import vace_1_3b


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class aura_sr_v2(FastClient):
    """
    Generated client for zsxkib/aura-sr-v2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e6bb9747-7fbb-43a8-8045-84b7379084f1", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], output_format: str = 'webp', max_batch_size: int = 8, output_quality: int = 80, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image to upscale
            
            output_format: The image file format of the generated output images Defaults to 'webp'.
            
            max_batch_size: Maximum number of tiles to process in a single batch. Higher values may increase speed but require more GPU memory. Defaults to 8.
            
            output_quality: The image compression quality (for lossy formats like JPEG and WebP). 100 = best quality, 0 = lowest quality. Defaults to 80.
            
        """
        return self.submit_job("/predictions", image=image, output_format=output_format, max_batch_size=max_batch_size, output_quality=output_quality, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class stable_diffusion(FastClient):
    """
    Generated client for stability-ai/stable-diffusion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2e7c4803-016e-4fd2-ab63-b3c25d4cad8d", api_key=api_key)
    
    def predictions(self, width: int = 768, height: int = 768, prompt: str = 'a vision of paradise. unreal engine', scheduler: str = 'DPMSolverMultistep', num_outputs: int = 1, guidance_scale: float = 7.5, num_inference_steps: int = 50, seed: Optional[int] = None, negative_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of generated image in pixels. Needs to be a multiple of 64 Defaults to 768.
            
            height: Height of generated image in pixels. Needs to be a multiple of 64 Defaults to 768.
            
            prompt: Input prompt Defaults to 'a vision of paradise. unreal engine'.
            
            scheduler: Choose a scheduler. Defaults to 'DPMSolverMultistep'.
            
            num_outputs: Number of images to generate. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            negative_prompt: Specify things to not see in the output Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, num_inference_steps=num_inference_steps, seed=seed, negative_prompt=negative_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class sticker_maker(FastClient):
    """
    Generated client for fofr/sticker-maker
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="3bd7cc24-4284-4b6b-bfe5-316473e6da6f", api_key=api_key)
    
    def predictions(self, steps: int = 17, width: int = 1152, height: int = 1152, prompt: str = 'a cute cat', output_format: str = 'webp', output_quality: int = 90, negative_prompt: str = '', number_of_images: int = 1, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            steps: steps Defaults to 17.
            
            width: width Defaults to 1152.
            
            height: height Defaults to 1152.
            
            prompt: prompt Defaults to 'a cute cat'.
            
            output_format: Format of the output images Defaults to 'webp'.
            
            output_quality: Quality of the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Defaults to 90.
            
            negative_prompt: Things you do not want in the image Defaults to ''.
            
            number_of_images: Number of images to generate Defaults to 1.
            
            seed: Fix the random seed for reproducibility Optional.
            
        """
        return self.submit_job("/predictions", steps=steps, width=width, height=height, prompt=prompt, output_format=output_format, output_quality=output_quality, negative_prompt=negative_prompt, number_of_images=number_of_images, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class addwatermark(FastClient):
    """
    Generated client for charlesmccarthy/addwatermark
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1f2e4a2e-b421-4a6e-8021-79ffb4fca4b3", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], size: int = 40, watermark: str = 'FULLJOURNEY.AI', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video
            
            size: Size of font Defaults to 40.
            
            watermark: Watermark Text Defaults to 'FULLJOURNEY.AI'.
            
        """
        return self.submit_job("/predictions", video=video, size=size, watermark=watermark, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.zsxkib.animate_diff import animate_diff
from socaity.sdk.replicate.zsxkib.animatediff_illusions import animatediff_illusions
from socaity.sdk.replicate.zsxkib.animatediff_prompt_travel import animatediff_prompt_travel
from socaity.sdk.replicate.zsxkib.aura_sr import aura_sr
from socaity.sdk.replicate.zsxkib.aura_sr_v2 import aura_sr_v2
from socaity.sdk.replicate.zsxkib.create_rvc_dataset import create_rvc_dataset
from socaity.sdk.replicate.zsxkib.diffbir import diffbir
from socaity.sdk.replicate.zsxkib.film_frame_interpolation_for_large_motion import film_frame_interpolation_for_large_motion
from socaity.sdk.replicate.zsxkib.flux_music import flux_music
from socaity.sdk.replicate.zsxkib.hunyuan_video2video import hunyuan_video2video
from socaity.sdk.replicate.zsxkib.ic_light_background import ic_light_background
from socaity.sdk.replicate.zsxkib.jina_clip_v2 import jina_clip_v2
from socaity.sdk.replicate.zsxkib.mimic_motion import mimic_motion
from socaity.sdk.replicate.zsxkib.mmaudio import mmaudio
from socaity.sdk.replicate.zsxkib.pyramid_flow import pyramid_flow
from socaity.sdk.replicate.zsxkib.realistic_voice_cloning import realistic_voice_cloning
from socaity.sdk.replicate.zsxkib.samurai import samurai
from socaity.sdk.replicate.zsxkib.stable_video_face_restoration import stable_video_face_restoration
from socaity.sdk.replicate.zsxkib.yolo_world import yolo_world


from socaity.sdk.replicate.sebastianbodza.flux_aquarell_watercolor_style import flux_aquarell_watercolor_style
from socaity.sdk.replicate.sebastianbodza.flux_lora_retro_linedrawing_style_v1 import flux_lora_retro_linedrawing_style_v1


from socaity.sdk.replicate.shapestudio.floating_flux import floating_flux
from socaity.sdk.replicate.shapestudio.nihon_flux import nihon_flux
from socaity.sdk.replicate.shapestudio.portra_800_flux import portra_800_flux
from socaity.sdk.replicate.shapestudio.wild_flux import wild_flux


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class deoldify_video(FastClient):
    """
    Generated client for arielreplicate/deoldify-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c65f8678-d8be-4042-b11e-e04d97122e91", api_key=api_key)
    
    def predictions(self, input_video: Union[MediaFile, str, bytes], render_factor: int = 21, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_video: Path to a video
            
            render_factor: The default value of 35 has been carefully chosen and should work -ok- for most scenarios (but probably won't be the -best-). This determines resolution at which the color portion of the image is rendered. Lower resolution will render faster, and colors also tend to look more vibrant. Older and lower quality images in particular will generally benefit by lowering the render factor. Higher render factors are often better for higher quality images, but the colors may get slightly washed out. Defaults to 21.
            
        """
        return self.submit_job("/predictions", input_video=input_video, render_factor=render_factor, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.cjwbw.controlvideo import controlvideo
from socaity.sdk.replicate.cjwbw.damo_text_to_video import damo_text_to_video
from socaity.sdk.replicate.cjwbw.parler_tts import parler_tts
from socaity.sdk.replicate.cjwbw.rembg import rembg
from socaity.sdk.replicate.cjwbw.rudalle_sr import rudalle_sr
from socaity.sdk.replicate.cjwbw.seamless_communication import seamless_communication
from socaity.sdk.replicate.cjwbw.semantic_segment_anything import semantic_segment_anything
from socaity.sdk.replicate.cjwbw.shap_e import shap_e
from socaity.sdk.replicate.cjwbw.supir import supir
from socaity.sdk.replicate.cjwbw.text2video_zero import text2video_zero
from socaity.sdk.replicate.cjwbw.videocrafter import videocrafter
from socaity.sdk.replicate.cjwbw.voicecraft import voicecraft


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class i2vgen_xl(FastClient):
    """
    Generated client for ali-vilab/i2vgen-xl
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="d199690f-be1a-4727-9e5e-f027245f461a", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], prompt: str, max_frames: int = 16, guidance_scale: float = 9.0, num_inference_steps: int = 50, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image.
            
            prompt: Describe the input image.
            
            max_frames: Number of frames in the output Defaults to 16.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 9.0.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, prompt=prompt, max_frames=max_frames, guidance_scale=guidance_scale, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class music_inpainting_bert(FastClient):
    """
    Generated client for andreasjansson/music-inpainting-bert
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="91a17309-ccf3-41e6-ab92-93c748f2fdfb", api_key=api_key)
    
    def predictions(self, notes: str, chords: str, seed: int = -1, tempo: int = 120, sample_width: int = 10, time_signature: int = 4, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            notes: Notes in tinynotation, with each bar separated by '|'. Use '?' for bars you want in-painted.
            
            chords: Chords (one chord per bar), with each bar separated by '|'. Use '?' for bars you want in-painted.
            
            seed: Random seed, -1 for random Defaults to -1.
            
            tempo: Tempo (beats per minute) Defaults to 120.
            
            sample_width: Number of potential predictions to sample from. The higher, the more chaotic the output. Defaults to 10.
            
            time_signature: Time signature Defaults to 4.
            
        """
        return self.submit_job("/predictions", notes=notes, chords=chords, seed=seed, tempo=tempo, sample_width=sample_width, time_signature=time_signature, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class sdxl_lightning(FastClient):
    """
    Generated client for prunaai/sdxl-lightning
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="46273539-afd7-4579-8690-cccd1971e722", api_key=api_key)
    
    def predictions(self, prompt: str, seed: int = 42, num_images: int = 1, image_width: int = 1024, image_height: int = 1024, output_format: str = 'jpg', guidance_scale: float = 0.0, output_quality: int = 80, num_inference_steps: int = 4, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt
            
            seed: Seed Defaults to 42.
            
            num_images: Number of images to generate Defaults to 1.
            
            image_width: Image width Defaults to 1024.
            
            image_height: Image height Defaults to 1024.
            
            output_format: Output format Defaults to 'jpg'.
            
            guidance_scale: Guidance scale Defaults to 0.0.
            
            output_quality: Output quality (for jpg and webp) Defaults to 80.
            
            num_inference_steps: Number of inference steps Defaults to 4.
            
        """
        return self.submit_job("/predictions", prompt=prompt, seed=seed, num_images=num_images, image_width=image_width, image_height=image_height, output_format=output_format, guidance_scale=guidance_scale, output_quality=output_quality, num_inference_steps=num_inference_steps, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class rudalle_sr(FastClient):
    """
    Generated client for cjwbw/rudalle-sr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ae44cda0-15db-4eee-be00-27a5b56446af", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], scale: int = 4, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            scale: Choose up-scaling factor Defaults to 4.
            
        """
        return self.submit_job("/predictions", image=image, scale=scale, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class codeformer(FastClient):
    """
    Generated client for sczhou/codeformer
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="3c7452a1-b283-46c8-ac17-64d7335e7782", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], upscale: int = 2, face_upsample: bool = True, background_enhance: bool = True, codeformer_fidelity: float = 0.5, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            upscale: The final upsampling scale of the image Defaults to 2.
            
            face_upsample: Upsample restored faces for high-resolution AI-created images Defaults to True.
            
            background_enhance: Enhance background image with Real-ESRGAN Defaults to True.
            
            codeformer_fidelity: Balance the quality (lower number) and fidelity (higher number). Defaults to 0.5.
            
        """
        return self.submit_job("/predictions", image=image, upscale=upscale, face_upsample=face_upsample, background_enhance=background_enhance, codeformer_fidelity=codeformer_fidelity, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class demofusion_enhance(FastClient):
    """
    Generated client for lucataco/demofusion-enhance
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2690a512-4e72-4970-93c3-da2639c720dd", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], scale: int = 2, sigma: float = 0.8, prompt: str = 'A high resolution photo', stride: int = 64, auto_prompt: bool = False, multi_decoder: bool = False, cosine_scale_1: float = 3.0, cosine_scale_2: float = 1.0, cosine_scale_3: float = 1.0, guidance_scale: float = 8.5, negative_prompt: str = 'blurry, ugly, duplicate, poorly drawn, deformed, mosaic', view_batch_size: int = 16, num_inference_steps: int = 40, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            scale: Scale factor for input image Defaults to 2.
            
            sigma: The standard value of the Gaussian filter Defaults to 0.8.
            
            prompt: Input prompt Defaults to 'A high resolution photo'.
            
            stride: The stride of moving local patches Defaults to 64.
            
            auto_prompt: Select to use auto-generated CLIP prompt instead of using the above custom prompt Defaults to False.
            
            multi_decoder: Use multiple decoders Defaults to False.
            
            cosine_scale_1: Control the strength of skip-residual Defaults to 3.0.
            
            cosine_scale_2: Control the strength of dilated sampling Defaults to 1.0.
            
            cosine_scale_3: Control the strength of the Gaussian filter Defaults to 1.0.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 8.5.
            
            negative_prompt: Input Negative Prompt Defaults to 'blurry, ugly, duplicate, poorly drawn, deformed, mosaic'.
            
            view_batch_size: The batch size for multiple denoising paths Defaults to 16.
            
            num_inference_steps: Number of denoising steps Defaults to 40.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, scale=scale, sigma=sigma, prompt=prompt, stride=stride, auto_prompt=auto_prompt, multi_decoder=multi_decoder, cosine_scale_1=cosine_scale_1, cosine_scale_2=cosine_scale_2, cosine_scale_3=cosine_scale_3, guidance_scale=guidance_scale, negative_prompt=negative_prompt, view_batch_size=view_batch_size, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class shap_e(FastClient):
    """
    Generated client for cjwbw/shap-e
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="01265335-2249-43c0-b787-453da9a6fbb0", api_key=api_key)
    
    def predictions(self, save_mesh: bool = False, batch_size: int = 1, render_mode: str = 'nerf', render_size: int = 128, guidance_scale: float = 15.0, image: Optional[Union[MediaFile, str, bytes]] = None, prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            save_mesh: Save the latents as meshes. Defaults to False.
            
            batch_size: Number of output Defaults to 1.
            
            render_mode: Choose a render mode Defaults to 'nerf'.
            
            render_size: Set the size of the a renderer, higher values take longer to render Defaults to 128.
            
            guidance_scale: Set the scale for guidanece Defaults to 15.0.
            
            image: A synthetic view image for generating the 3D modeld. To get the best result, remove background from the input image Optional.
            
            prompt: Text prompt for generating the 3D model, ignored if an image is provide below Optional.
            
        """
        return self.submit_job("/predictions", save_mesh=save_mesh, batch_size=batch_size, render_mode=render_mode, render_size=render_size, guidance_scale=guidance_scale, image=image, prompt=prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


import pytest
import os
from test_socaity.test_face2face import test_face2face
from test_socaity.test_spechcraft import test_speechcraft

from test_replicate.test_flux_schnell import test_text2img
from test_replicate.test_deepseek import test_deepseek_v3
from test_replicate.test_llama3 import test_llama_models
from test_replicate.test_sam2 import test_sam2
from test_replicate.test_whisper import test_transcribe


class TestModels:
    """Integration tests that run multiple models in sequence"""
    
    @pytest.fixture(autouse=True)
    def setup(self):
        """Setup for integration tests"""
        self.api_key = os.getenv("SOCAITY_API_KEY")
        if not self.api_key:
            pytest.skip("SOCAITY_API_KEY environment variable not set")
    
    @pytest.mark.socaity
    def test_all_socaity_models(self):
        """Test all Socaity models"""
        socaity_tests = [test_face2face, test_speechcraft]
        
        for test_func in socaity_tests:
            try:
                result = test_func()
                assert result is True, f"Test {test_func.__name__} failed"
            except Exception as e:
                pytest.fail(f"Socaity test {test_func.__name__} failed: {str(e)}")
    
    @pytest.mark.replicate
    def test_all_replicate_models(self):
        """Test all Replicate models"""
        tests = [
            test_text2img,
            test_llama_models,
            test_deepseek_v3,
            test_sam2,
            test_transcribe
        ]
        
        results = []
        for test_func in tests:
            try:
                test_func()
                results.append((test_func.__name__, True, None))
            except Exception as e:
                results.append((test_func.__name__, False, str(e)))
        
        # Check that at least some tests passed
        passed_tests = [r for r in results if r[1]]
        assert len(passed_tests) > 0, f"No tests passed. Results: {results}"
        
        # Report any failures but don't fail the whole test
        failed_tests = [r for r in results if not r[1]]
        if failed_tests:
            print(f"Some tests failed: {failed_tests}")


if __name__ == "__main__":
    # Run all tests
    # pytest socaity/test/test_models.py -v
    #  Run only Socaity model tests
    # pytest socaity/test/test_models.py -v -m socaity
    # Run only Replicate model tests  
    # pytest socaity/test/test_models.py -v -m replicate
    # Run the entire TestModels class
    # pytest socaity/test/test_models.py::TestModels -v
    # Run with pytest when called directly
    pytest.main([__file__, "-v"])



from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class deep3d(FastClient):
    """
    Generated client for lucataco/deep3d
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2a83dbc4-4a08-4d65-bc04-8192adf0324b", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], model: str = 'deep3d_v1.0_640x360', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video
            
            model: Model size Defaults to 'deep3d_v1.0_640x360'.
            
        """
        return self.submit_job("/predictions", video=video, model=model, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class yolo_world(FastClient):
    """
    Generated client for zsxkib/yolo-world
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="41a54615-ab8a-4af0-ac7e-19c1d5378234", api_key=api_key)
    
    def predictions(self, input_media: Union[MediaFile, str, bytes], nms_thr: float = 0.5, score_thr: float = 0.05, class_names: str = 'dog, eye, tongue, ear, leash, backpack, person, nose', max_num_boxes: int = 100, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_media: Path to the input image or video
            
            nms_thr: NMS threshold Defaults to 0.5.
            
            score_thr: Score threshold for displaying bounding boxes Defaults to 0.05.
            
            class_names: Enter the classes to be detected, separated by comma Defaults to 'dog, eye, tongue, ear, leash, backpack, person, nose'.
            
            max_num_boxes: Maximum number of bounding boxes to display Defaults to 100.
            
        """
        return self.submit_job("/predictions", input_media=input_media, nms_thr=nms_thr, score_thr=score_thr, class_names=class_names, max_num_boxes=max_num_boxes, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class realvisxl_v3_multi_controlnet_lora(FastClient):
    """
    Generated client for fofr/realvisxl-v3-multi-controlnet-lora
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bbe719d7-e19e-4f33-b04b-870615ae2534", api_key=api_key)
    
    def predictions(self, width: int = 768, height: int = 768, prompt: str = 'An astronaut riding a rainbow unicorn', refine: str = 'no_refiner', scheduler: str = 'K_EULER', lora_scale: float = 0.6, num_outputs: int = 1, controlnet_1: str = 'none', controlnet_2: str = 'none', controlnet_3: str = 'none', guidance_scale: float = 7.5, apply_watermark: bool = False, negative_prompt: str = '', prompt_strength: float = 0.8, sizing_strategy: str = 'width_height', controlnet_1_end: float = 1.0, controlnet_2_end: float = 1.0, controlnet_3_end: float = 1.0, controlnet_1_start: float = 0.0, controlnet_2_start: float = 0.0, controlnet_3_start: float = 0.0, num_inference_steps: int = 30, disable_safety_checker: bool = False, controlnet_1_conditioning_scale: float = 0.75, controlnet_2_conditioning_scale: float = 0.75, controlnet_3_conditioning_scale: float = 0.75, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, lora_weights: Optional[str] = None, refine_steps: Optional[int] = None, controlnet_1_image: Optional[Union[MediaFile, str, bytes]] = None, controlnet_2_image: Optional[Union[MediaFile, str, bytes]] = None, controlnet_3_image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 768.
            
            height: Height of output image Defaults to 768.
            
            prompt: Input prompt Defaults to 'An astronaut riding a rainbow unicorn'.
            
            refine: Which refine style to use Defaults to 'no_refiner'.
            
            scheduler: scheduler Defaults to 'K_EULER'.
            
            lora_scale: LoRA additive scale. Only applicable on trained models. Defaults to 0.6.
            
            num_outputs: Number of images to output Defaults to 1.
            
            controlnet_1: Controlnet Defaults to 'none'.
            
            controlnet_2: Controlnet Defaults to 'none'.
            
            controlnet_3: Controlnet Defaults to 'none'.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to False.
            
            negative_prompt: Negative Prompt Defaults to ''.
            
            prompt_strength: Prompt strength when using img2img / inpaint. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            sizing_strategy: Decide how to resize images – use width/height, resize based on input image or control image Defaults to 'width_height'.
            
            controlnet_1_end: When controlnet conditioning ends Defaults to 1.0.
            
            controlnet_2_end: When controlnet conditioning ends Defaults to 1.0.
            
            controlnet_3_end: When controlnet conditioning ends Defaults to 1.0.
            
            controlnet_1_start: When controlnet conditioning starts Defaults to 0.0.
            
            controlnet_2_start: When controlnet conditioning starts Defaults to 0.0.
            
            controlnet_3_start: When controlnet conditioning starts Defaults to 0.0.
            
            num_inference_steps: Number of denoising steps Defaults to 30.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. Defaults to False.
            
            controlnet_1_conditioning_scale: How strong the controlnet conditioning is Defaults to 0.75.
            
            controlnet_2_conditioning_scale: How strong the controlnet conditioning is Defaults to 0.75.
            
            controlnet_3_conditioning_scale: How strong the controlnet conditioning is Defaults to 0.75.
            
            mask: Input mask for inpaint mode. Black areas will be preserved, white areas will be inpainted. Optional.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
            lora_weights: Replicate LoRA weights to use. Leave blank to use the default weights. Optional.
            
            refine_steps: For base_image_refiner, the number of steps to refine, defaults to num_inference_steps Optional.
            
            controlnet_1_image: Input image for first controlnet Optional.
            
            controlnet_2_image: Input image for second controlnet Optional.
            
            controlnet_3_image: Input image for third controlnet Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, refine=refine, scheduler=scheduler, lora_scale=lora_scale, num_outputs=num_outputs, controlnet_1=controlnet_1, controlnet_2=controlnet_2, controlnet_3=controlnet_3, guidance_scale=guidance_scale, apply_watermark=apply_watermark, negative_prompt=negative_prompt, prompt_strength=prompt_strength, sizing_strategy=sizing_strategy, controlnet_1_end=controlnet_1_end, controlnet_2_end=controlnet_2_end, controlnet_3_end=controlnet_3_end, controlnet_1_start=controlnet_1_start, controlnet_2_start=controlnet_2_start, controlnet_3_start=controlnet_3_start, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, controlnet_1_conditioning_scale=controlnet_1_conditioning_scale, controlnet_2_conditioning_scale=controlnet_2_conditioning_scale, controlnet_3_conditioning_scale=controlnet_3_conditioning_scale, mask=mask, seed=seed, image=image, lora_weights=lora_weights, refine_steps=refine_steps, controlnet_1_image=controlnet_1_image, controlnet_2_image=controlnet_2_image, controlnet_3_image=controlnet_3_image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class metavoice(FastClient):
    """
    Generated client for camenduru/metavoice
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0c2da908-6738-4a6f-a4a0-7e289389d18b", api_key=api_key)
    
    def predictions(self, input_audio: Union[MediaFile, str, bytes], text: str = 'This is a demo of text to speech by MetaVoice-1B, an open-source foundational audio model by MetaVoice.', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_audio: Input Image
            
            text: text Defaults to 'This is a demo of text to speech by MetaVoice-1B, an open-source foundational audio model by MetaVoice.'.
            
        """
        return self.submit_job("/predictions", input_audio=input_audio, text=text, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class rembg_video(FastClient):
    """
    Generated client for lucataco/rembg-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="26f1e220-7c28-4bd5-aef1-9ca64b2fe2e2", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], mode: str = 'Normal', background_color: str = '#FFFFFF', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Grayscale input image
            
            mode: Mode of operation Defaults to 'Normal'.
            
            background_color: Background color in hex format (e.g., '#FFFFFF' for white) Defaults to '#FFFFFF'.
            
        """
        return self.submit_job("/predictions", video=video, mode=mode, background_color=background_color, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class realistic_vision_v5_1(FastClient):
    """
    Generated client for lucataco/realistic-vision-v5-1
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="683a17b4-ae06-4450-9fc5-907a3300d5da", api_key=api_key)
    
    def predictions(self, seed: int = 0, steps: int = 20, width: int = 512, height: int = 728, prompt: str = 'RAW photo, a portrait photo of a latina woman in casual clothes, natural skin, 8k uhd, high quality, film grain, Fujifilm XT3', guidance: float = 5.0, scheduler: str = 'EulerA', negative_prompt: str = '(deformed iris, deformed pupils, semi-realistic, cgi, 3d, render, sketch, cartoon, drawing, anime:1.4), text, close up, cropped, out of frame, worst quality, low quality, jpeg artifacts, ugly, duplicate, morbid, mutilated, extra fingers, mutated hands, poorly drawn hands, poorly drawn face, mutation, deformed, blurry, dehydrated, bad anatomy, bad proportions, extra limbs, cloned face, disfigured, gross proportions, malformed limbs, missing arms, missing legs, extra arms, extra legs, fused fingers, too many fingers, long neck', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Seed (0 = random, maximum: 2147483647) Defaults to 0.
            
            steps:  num_inference_steps Defaults to 20.
            
            width: Width Defaults to 512.
            
            height: Height Defaults to 728.
            
            prompt: prompt Defaults to 'RAW photo, a portrait photo of a latina woman in casual clothes, natural skin, 8k uhd, high quality, film grain, Fujifilm XT3'.
            
            guidance: Guidance scale (3.5 - 7) Defaults to 5.0.
            
            scheduler: Choose a scheduler Defaults to 'EulerA'.
            
            negative_prompt: negative_prompt Defaults to '(deformed iris, deformed pupils, semi-realistic, cgi, 3d, render, sketch, cartoon, drawing, anime:1.4), text, close up, cropped, out of frame, worst quality, low quality, jpeg artifacts, ugly, duplicate, morbid, mutilated, extra fingers, mutated hands, poorly drawn hands, poorly drawn face, mutation, deformed, blurry, dehydrated, bad anatomy, bad proportions, extra limbs, cloned face, disfigured, gross proportions, malformed limbs, missing arms, missing legs, extra arms, extra legs, fused fingers, too many fingers, long neck'.
            
        """
        return self.submit_job("/predictions", seed=seed, steps=steps, width=width, height=height, prompt=prompt, guidance=guidance, scheduler=scheduler, negative_prompt=negative_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class phixtral_2x2_8(FastClient):
    """
    Generated client for lucataco/phixtral-2x2-8
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e0465400-c5e2-4bec-bb79-ffd83cf47fe7", api_key=api_key)
    
    def predictions(self, prompt: str, top_k: int = 50, top_p: float = 0.95, temperature: float = 0.7, max_new_tokens: int = 1024, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            prompt: Input prompt
            
            top_k: Top k Defaults to 50.
            
            top_p: Top p Defaults to 0.95.
            
            temperature: Temperature Defaults to 0.7.
            
            max_new_tokens: Max new tokens Defaults to 1024.
            
            seed: The seed for the random number generator Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_k=top_k, top_p=top_p, temperature=temperature, max_new_tokens=max_new_tokens, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class riffusion(FastClient):
    """
    Generated client for riffusion/riffusion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="043a836f-f6d6-4f1a-b0c1-18d68428b666", api_key=api_key)
    
    def predictions(self, alpha: float = 0.5, prompt_a: str = 'funky synth solo', denoising: float = 0.75, seed_image_id: str = 'vibes', num_inference_steps: int = 50, prompt_b: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            alpha: Interpolation alpha if using two prompts. A value of 0 uses prompt_a fully, a value of 1 uses prompt_b fully Defaults to 0.5.
            
            prompt_a: The prompt for your audio Defaults to 'funky synth solo'.
            
            denoising: How much to transform input spectrogram Defaults to 0.75.
            
            seed_image_id: Seed spectrogram to use Defaults to 'vibes'.
            
            num_inference_steps: Number of steps to run the diffusion model Defaults to 50.
            
            prompt_b: The second prompt to interpolate with the first, leave blank if no interpolation Optional.
            
        """
        return self.submit_job("/predictions", alpha=alpha, prompt_a=prompt_a, denoising=denoising, seed_image_id=seed_image_id, num_inference_steps=num_inference_steps, prompt_b=prompt_b, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class clip_features(FastClient):
    """
    Generated client for andreasjansson/clip-features
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c0c833f2-2dc4-43b5-8c2a-09bf8d70c89c", api_key=api_key)
    
    def predictions(self, inputs: str = 'a\nb', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            inputs: Newline-separated inputs. Can either be strings of text or image URIs starting with http[s]:// Defaults to 'a\nb'.
            
        """
        return self.submit_job("/predictions", inputs=inputs, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions